@@ -136,11 +136,10 @@ vuongtest <- function(object1, object2, nested=FALSE, adj="none", ll1=llcont, ll
   ## pOmega <- tmp[[4]]
   pOmega <- imhof(n * omega.hat.2, lamstar^2)$Qq
 
-  ## Calculate and test LRT; Eq (6.4)
+  ## Calculate likelihood ratio; Eq (6.4)
   lr <- sum(llA - llB, na.rm = TRUE)
-  teststat <- (1/sqrt(n)) * lr/sqrt(omega.hat.2)
 
-  ## Adjustments to test statistics
+  ## Adjustments to likelihood ratio
   ## FIXME lavaan equality constraints; use df instead?
   if(classA %in% c("SingleGroupClass", "MultipleGroupClass")){
     nparA <- mirt::extract.mirt(object1, "nest")
@@ -154,12 +153,14 @@ vuongtest <- function(object1, object2, nested=FALSE, adj="none", ll1=llcont, ll
   }
   
   if(adj=="aic"){
-    teststat <- teststat - (nparA - nparB)
+    lr <- lr - (nparA - nparB)
   }
   if(adj=="bic"){
-    teststat <- teststat - (nparA - nparB) * log(n)/2
+    lr <- lr - (nparA - nparB) * log(n)/2
   }
 
+  teststat <- (1/sqrt(n)) * lr/sqrt(omega.hat.2)
+
   ## Null distribution and test stat depend on nested
   if(nested){
       teststat <- 2 * lr
@@ -233,8 +234,13 @@ calcAB <- function(object, n, scfun, vc){
     sc <- scfun(object)
   } else if(class(object)[1] == "lavaan"){
     sc <- estfun(object, remove.duplicated=TRUE)
-  } else if (class(object)[1] %in% c("SingleGroupClass", "MultipleGroupClass")){
-    sc <- mirt::estfun.AllModelClass(object)
+  } else if(class(object)[1] %in% c("SingleGroupClass", "MultipleGroupClass")){
+    wts <- mirt::extract.mirt(object, "survey.weights")
+    if(length(wts) > 0){
+      sc <- mirt::estfun.AllModelClass(object, weights = sqrt(wts))
+    } else {
+      sc <- mirt::estfun.AllModelClass(object)
+    }
   } else if(class(object)[1] %in% c("lm", "glm", "nls")){
     sc <- (1/scaling) * estfun(object)
   } else {
@@ -327,6 +333,11 @@ check.obj <- function(object1, object2) {
     } else {
       callA <- object1@call
     }
+    if(classA == "lavaan"){
+      if(length(object1@Data@weights[[1]]) > 0){
+        stop("lavaan objects with sampling weights are not currently supported")
+      }
+    }
   } else {
     callA <- object1$call
   }
@@ -337,6 +348,11 @@ check.obj <- function(object1, object2) {
     } else {
       callB <- object2@call
     }
+    if(classB == "lavaan"){
+      if(length(object2@Data@weights[[1]]) > 0){
+        stop("lavaan objects with sampling weights are not currently supported")
+      }
+    }
   } else {
     callB <- object2$call
   }
